var fs = require("fs");
var http = require("http");
var url = require("url");
var path = require("path");
var cache = require("./cache.js");
var log = require("./log.js");



function maintain(name, repoinfo, files) {
	log.info("Starting maintenance routine for yum repo %s (%s)", name, repoinfo.url);
	
	var metaAge = 24*3600*1000*(repoinfo.updateinterval);
	var expireAge = 24*3600*1000*(repoinfo.expiretime);
	
	function fileCheck(i) {
		log.debug("checking file: ", files[i]);
		
		// we look for repodata/repomd.xml file, if this is past maturity, we clean that whole directory
		if(files[i].match(/.*repodata\/repomd\.xml$/)) {
			log.debug("Found repomd.xml file: ", files[i]);
			
			// strip the repomd file to get the dir
			var repomddir = files[i].replace(/repomd\.xml$/, "");
			log.debug("repomd dir is:", repomddir);

			
			// do the file stat
			fs.stat(files[i], function(err, stats) {
				log.debug("stats for file was: ", stats);
				var curtime = new Date().getTime();
				var ctime = stats.ctime.getTime();
				log.debug("curtime is ", curtime);
				log.debug("ctime is ", ctime);
				
				var age = curtime - ctime;
				log.debug("age is (%d) for (%d)", age, metaAge);
				if(age > metaAge) {
					cache.moveToCleanup(repomddir);
					log.info("Sending repomd directory to trash for cleanup (%s)", repomddir);
				}
			})
			
		} else {
			// STUFF!!!
			fs.stat(files[i], function(err, stats) {
				log.debug("stats for file was: ", stats);
				var curtime = new Date().getTime();
				var atime = stats.atime.getTime();
				log.debug("curtime is ", curtime);
				log.debug("ctime is ", atime);
				
				var age = curtime - atime;
				//log.debug("age is (%d) for (%d)", age, expireAge);
				if(age > expireAge) {
					// TODO: cleanup singular file
					// TODO: cleanup meta too, fuck me
					//log.debug("clean up file \n", files[i]);
					var metafile = files[i].replace(/(.*)\/(.[^\/]+$)/, "$1/.meta.$2.filesize");
					//log.debug("meta for this file is \n", nfile);
					cache.moveToCleanup(files[i]);
					cache.moveToCleanup(metafile);
					log.info("Sending expired file to trash for cleanup (%s)", files[i]);
				}
			})
		}

		if(typeof files[i+1] != "undefined") fileCheck(i+1);				
	}
	
	if(typeof files[0] != 'undefined') fileCheck(0)
	else log.info("Skipping (yum) file check as there are none... apprently?");

}

exports.maintain = maintain;